@@ -1,10 +1,10 @@
 from dagster.core.utils import check_dagster_package_version
 
+from .executor import k8s_job_executor
 from .job import DagsterK8sJobConfig, construct_dagster_k8s_job
 from .launcher import K8sRunLauncher
-from .scheduler import K8sScheduler
 from .version import __version__
 
 check_dagster_package_version("dagster-k8s", __version__)
 
-__all__ = ["K8sRunLauncher", "K8sScheduler"]
+__all__ = ["K8sRunLauncher"]
